summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNicolás Reynolds <fauno@kiwwwi.com.ar>2011-08-03 16:11:36 -0300
committerNicolás Reynolds <fauno@kiwwwi.com.ar>2011-08-03 16:11:36 -0300
commitda9ed1038f53c8b3cd350e8efafb3146d3e16795 (patch)
tree560bd49be0ee5d1489e01548ec9ee77df60c75e0
parent91210f8ae18f5651ace2273cfa0c8ad7e4dbcbdf (diff)
parentc26ba3ccee6700bc0be0031df959d96918f7800f (diff)
Merge branch 'master' of https://projects.archlinux.org/git/dbscripts
-rwxr-xr-xcron-jobs/check_archlinux/parse_pkgbuilds.sh8
-rwxr-xr-xdb-remove3
-rw-r--r--test/lib/common.inc2
-rwxr-xr-xtest/test.d/packages.sh4
4 files changed, 12 insertions, 5 deletions
diff --git a/cron-jobs/check_archlinux/parse_pkgbuilds.sh b/cron-jobs/check_archlinux/parse_pkgbuilds.sh
index 5cd17e4..3f92169 100755
--- a/cron-jobs/check_archlinux/parse_pkgbuilds.sh
+++ b/cron-jobs/check_archlinux/parse_pkgbuilds.sh
@@ -6,7 +6,7 @@
exit() { return; }
splitpkg_overrides=('depends' 'optdepends' 'provides' 'conflicts')
-variables=('pkgname' 'pkgbase' 'pkgver' 'pkgrel' 'makedepends' 'arch' ${splitpkg_overrides[@]})
+variables=('pkgname' 'pkgbase' 'epoch' 'pkgver' 'pkgrel' 'makedepends' 'arch' ${splitpkg_overrides[@]})
readonly -a variables splitpkg_overrides
backup_package_variables() {
@@ -29,7 +29,11 @@ restore_package_variables() {
print_info() {
echo -e "%NAME%\n$pkgname\n"
- echo -e "%VERSION%\n$pkgver-$pkgrel\n"
+ if [ -n "$epoch" ]; then
+ echo -e "%VERSION%\n$epoch:$pkgver-$pkgrel\n"
+ else
+ echo -e "%VERSION%\n$pkgver-$pkgrel\n"
+ fi
echo -e "%PATH%\n$dir\n"
if [ -n "$pkgbase" ]; then
diff --git a/db-remove b/db-remove
index 292af5d..b44eb33 100755
--- a/db-remove
+++ b/db-remove
@@ -38,6 +38,9 @@ if [ -d "${WORKDIR}/svn/$pkgbase/repos/$svnrepo" ]; then
/usr/bin/svn commit -q "${WORKDIR}/svn/$pkgbase" -m "$(basename $0): $pkgbase removed by $(id -un)"
else
warning "$pkgbase not found in $svnrepo"
+ warning "Removing only $pkgbase from the repo"
+ warning "If it was a split package you have to remove the others yourself!"
+ pkgnames=($pkgbase)
fi
for tarch in ${tarches[@]}; do
diff --git a/test/lib/common.inc b/test/lib/common.inc
index eb46508..c96e677 100644
--- a/test/lib/common.inc
+++ b/test/lib/common.inc
@@ -11,7 +11,7 @@ oneTimeSetUp() {
local pkgarch
local pkgversion
local build
- pkgdir="$(mktemp -d /dev/shm/$(basename $0).XXXXXXXXXX)"
+ pkgdir="$(mktemp -d /tmp/$(basename $0).XXXXXXXXXX)"
cp -Lr $(dirname ${BASH_SOURCE[0]})/../packages/* "${pkgdir}"
msg 'Building packages...'
for d in "${pkgdir}"/*; do
diff --git a/test/test.d/packages.sh b/test/test.d/packages.sh
index 324f73a..488cb15 100755
--- a/test/test.d/packages.sh
+++ b/test/test.d/packages.sh
@@ -4,8 +4,8 @@ curdir=$(readlink -e $(dirname $0))
. "${curdir}/../lib/common.inc"
testPackages() {
- # TODO: namcap -r depends fails with i686 packages
- find "${pkgdir}" -name "*${PKGEXT}" -exec namcap -e depends {} + || fail 'namcap failed'
+ # TODO: namcap -r sodepends fails with i686 packages
+ find "${pkgdir}" -name "*${PKGEXT}" -exec namcap -e sodepends,pkgnameindesc {} + || fail 'namcap failed'
}
. "${curdir}/../lib/shunit2"